/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Multifox.
 *
 * The Initial Developer of the Original Code is
 * Jeferson Hultmann <hultmann@gmail.com>
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const EXPORTED_SYMBOLS = ["onDOMContentLoaded"];
Components.utils.import("resource://multifox-modules/util.js");

function onDOMContentLoaded(evt) {
  util.log("browser.xul DOMContentLoaded");
  var win = evt.currentTarget;


  setWindowProfile(win)
  var doc = win.document;

  //if ((doc instanceof Components.interfaces.nsIDOMDocument) === false) {
  //}


  // detect session restore
  doc.addEventListener("SSTabRestoring", onTabRestoring, false);

  // menus
  doc.getAnonymousElementByAttribute(doc.getElementById("content"), "anonid", "tabContextMenu")
     .addEventListener("popupshowing", onMenuPopupShowing, false);
  addMenuListener(doc, "contentAreaContextMenu");
  addMenuListener(doc, "placesContext");
  addMenuListener(doc, "menu_FilePopup");

  //
  win.removeEventListener("DOMContentLoaded", onDOMContentLoaded, false);
  util.log("/browser.xul DOMContentLoaded");
}

function setWindowProfile(newWin) {
  var winOpener = newWin.opener;
  if (winOpener) {
    var cmd = winOpener.document.getUserData("multifox-temp-start-new-identity-flag");
    if (cmd === "new!") {
      util.log("setWindowProfile => newProfile " + cmd);
      winOpener.document.setUserData("multifox-temp-start-new-identity-flag", null, null);
      Components.utils.import("resource://multifox-modules/main.js");
      NewWindow.newId(newWin);
      return;
    }
  }

  // inherit identity profile
  if (util.networkListeners.active) {
    //window.open()/fxstarting ==> winOpener=null
    Components.utils.import("resource://multifox-modules/main.js");
    NewWindow.inheritId(newWin, winOpener);
  } else {
    util.log("setWindowProfile => util.networkListeners.active=false");
  }
}


function onTabRestoring(evt) {
  var doc = evt.currentTarget;
  var win = doc.defaultView;

  // we need to [re]configure identity window id,
  // only the first restored tab is necessary.
  doc.removeEventListener("SSTabRestoring", onTabRestoring, false);

  var stringId = Components.classes["@mozilla.org/browser/sessionstore;1"]
                  .getService(Components.interfaces.nsISessionStore)
                  .getWindowValue(win, "multifox-dom-identity-id");

  if (util.networkListeners.active === false && stringId.length === 0) {
    // default scenario
    util.log("first tab restoring NOP");
    return;
  }

  util.log("first tab restoring " + stringId);

  // add icon; sync id  override any previous profile id
  Components.utils.import("resource://multifox-modules/main.js");
  NewWindow.applyRestore(win);
}


function onMenuPopupShowing(evt) {
  Components.utils.import("resource://multifox-modules/menus.js");
  menuShowing(evt);
}

function addMenuListener(doc, id) {
  doc.getElementById(id).addEventListener("popupshowing", onMenuPopupShowing, false);
}
